<!-- Fixes #xxx -->

<!-- For the PR title, follow a conventional commit message style: https://compwa-org.readthedocs.io/en/stable/develop.html#commit-conventions -->

<!-- Contents of this PR appear in the release notes. Please use screenshots, code snippets etc. to illustrate proposed changes -->
